==> haskell-ansi-terminal-1.0.2-50-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ansi-terminal.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ansi-terminal
version:              1.0.2
visibility:           public
id:                   ansi-terminal-1.0.2-HPtVnAU9d4e2sgA8soPDqO
key:                  ansi-terminal-1.0.2-HPtVnAU9d4e2sgA8soPDqO
license:              BSD-3-Clause
maintainer:
    Mike Pilgrem <public@pilgrem.com>, Roman Cheplyaka <roma@ro-che.info>

author:               Max Bolingbroke
homepage:             https://github.com/UnkindPartition/ansi-terminal
synopsis:             Simple ANSI terminal support
description:
    ANSI terminal support for Haskell: allows cursor movement,
    screen clearing, color output, showing or hiding the
    cursor, and changing the title. Works on UNIX and Windows.

category:             User Interfaces
abi:                  72eb4f421e28839bfcb5b6cb01688000
exposed:              True
exposed-modules:
    System.Console.ANSI, System.Console.ANSI.Codes,
    System.Console.ANSI.Types from ansi-terminal-types-0.11.5-909APIFFN6LJ6fUnvHSuhn:System.Console.ANSI.Types

hidden-modules:       System.Console.ANSI.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/ansi-terminal-1.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/ansi-terminal-1.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/ansi-terminal-1.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ansi-terminal
hs-libraries:         HSansi-terminal-1.0.2-HPtVnAU9d4e2sgA8soPDqO
depends:
    ansi-terminal-types-0.11.5-909APIFFN6LJ6fUnvHSuhn base-4.17.2.1
    colour-2.3.6-HxDVfr6wWPXfTiamMY1cb

haddock-interfaces:
    /usr/share/doc/haskell-ansi-terminal/html/ansi-terminal.haddock

haddock-html:         /usr/share/doc/haskell-ansi-terminal/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ansi-terminal-1.0.2-52-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ansi-terminal.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ansi-terminal
version:              1.0.2
visibility:           public
id:                   ansi-terminal-1.0.2-BmYwE3CMMeiHUDLKLgejP7
key:                  ansi-terminal-1.0.2-BmYwE3CMMeiHUDLKLgejP7
license:              BSD-3-Clause
maintainer:
    Mike Pilgrem <public@pilgrem.com>, Roman Cheplyaka <roma@ro-che.info>

author:               Max Bolingbroke
homepage:             https://github.com/UnkindPartition/ansi-terminal
synopsis:             Simple ANSI terminal support
description:
    ANSI terminal support for Haskell: allows cursor movement,
    screen clearing, color output, showing or hiding the
    cursor, and changing the title. Works on UNIX and Windows.

category:             User Interfaces
abi:                  c9d33a5f924747089101b6e771fa0dbf
exposed:              True
exposed-modules:
    System.Console.ANSI, System.Console.ANSI.Codes,
    System.Console.ANSI.Types from ansi-terminal-types-0.11.5-1u5O4f6d3X95YdnR2VjC1t:System.Console.ANSI.Types

hidden-modules:       System.Console.ANSI.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/ansi-terminal-1.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/ansi-terminal-1.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/ansi-terminal-1.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ansi-terminal
hs-libraries:         HSansi-terminal-1.0.2-BmYwE3CMMeiHUDLKLgejP7
depends:
    ansi-terminal-types-0.11.5-1u5O4f6d3X95YdnR2VjC1t base-4.17.2.1
    colour-2.3.6-A3AGod92PMIEixYbXwcaJk

haddock-interfaces:
    /usr/share/doc/haskell-ansi-terminal/html/ansi-terminal.haddock

haddock-html:         /usr/share/doc/haskell-ansi-terminal/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
